pub enum FormFactor {
ExternalDisplay,
InternalDisplay,
Remote,
}Expand description
Specifies how the tablet is integrated.
Variants
ExternalDisplay
The tablet is integrated into a display, e.g. a Wacom Cintiq.
InternalDisplay
The tablet is integrated into the display of a system, e.g. a built-in tablet in a laptop.
Remote
The tablet is an external remote like the Wacom ExpressKey Remote.