CacheBuilder

Struct CacheBuilder 

pub struct CacheBuilder { /* private fields */ }
Builder struct for a tablet Cache.

This builder is only required for adding non-default include paths, use Cache::new() for a tablet cache that uses the defaults.

Implementations

Source

impl CacheBuilder

pub fn new() -> Self

Create a new, empty, CacheBuilder without any include paths. This info is only needed where include paths need to be modified, for standard invocations use Cache::new().

The typical invocation is

let cache = CacheBuilder::new()
                .add_default_includes()
                .build()?;

The above example is equivalent to Cache::new().

pub fn add_default_includes(self) -> Self

Add the default set of include paths as compiled in, typically:

  • /usr/share/libwacom,
  • /etc/libwacom
  • $XDG_CONFIG_HOME/libwacom.
pub fn add_include(self, path: &Path) -> Self

Add an include path at the current position. Include paths are processed in-order with a file in most recent path obscuring a file with the same name in an earlier include path.

Include paths to not need to exist, empty or non-existing include paths are ignored.

pub fn build(self) -> Result<Cache, Error>

Create a tablet Cache from the current include paths.